@@ -4,13 +4,10 @@ from django.db.models.signals import post_save
 class DirtyFieldsMixin(object):
     def __init__(self, *args, **kwargs):
         super(DirtyFieldsMixin, self).__init__(*args, **kwargs)
-        post_save.connect(self._reset_state, sender=self.__class__, 
+        post_save.connect(reset_state, sender=self.__class__, 
                             dispatch_uid='%s-DirtyFieldsMixin-sweeper' % self.__class__.__name__)
-        self._reset_state()
-    
-    def _reset_state(self, *args, **kwargs):
-        self._original_state = self._as_dict()
-    
+        reset_state(sender=self.__class__, instance=self)
+
     def _as_dict(self):
         return dict([(f.name, getattr(self, f.name)) for f in self._meta.local_fields if not f.rel])
     
@@ -25,3 +22,5 @@ class DirtyFieldsMixin(object):
             return True
         return {} != self.get_dirty_fields()
 
+def reset_state(sender, instance, **kwargs):
+    instance._original_state = instance._as_dict()
